@@ -1,6 +1,6 @@
 /* gdaui-entry-wrapper.c
  *
- * Copyright (C) 2003 - 2009 Vivien Malerba
+ * Copyright (C) 2003 - 2010 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -105,7 +105,8 @@ gdaui_entry_wrapper_get_type (void)
 			NULL,
 			sizeof (GdauiEntryWrapper),
 			0,
-			(GInstanceInitFunc) gdaui_entry_wrapper_init
+			(GInstanceInitFunc) gdaui_entry_wrapper_init,
+			0
 		};
 
 		static const GInterfaceInfo data_entry_info = {
@@ -309,6 +310,9 @@ gdaui_entry_wrapper_set_property (GObject *object,
 					gda_value_free (sane_value);
 			}
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
 		}
 		}
 	}
@@ -326,12 +330,15 @@ gdaui_entry_wrapper_get_property (GObject *object,
 		case PROP_SET_DEFAULT_IF_INVALID:
 			g_value_set_boolean (value, mgwrap->priv->set_default_if_invalid);
 			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+			break;
 		}
 	}
 }
 
 /**
- * gdaui_entry_wrapper_contents_changed
+ * gdaui_entry_wrapper_contents_changed:
  * @mgwrap: a #GdauiEntryWrapper widget
  *
  * Signals to @gwrap that the entry has changed
@@ -345,7 +352,7 @@ gdaui_entry_wrapper_contents_changed (GdauiEntryWrapper *mgwrap)
 }
 
 /**
- * gdaui_entry_wrapper_contents_activated
+ * gdaui_entry_wrapper_contents_activated:
  * @mgwrap: a #GdauiEntryWrapper widget
  *
  * Signals to @gwrap that the entry has been activated (that is the user
@@ -362,7 +369,7 @@ gdaui_entry_wrapper_contents_activated (GdauiEntryWrapper *mgwrap)
 
 static void gdaui_entry_wrapper_emit_signal (GdauiEntryWrapper *mgwrap);
 static void
-contents_changed_cb (GtkWidget *entry, GdauiEntryWrapper *mgwrap)
+contents_changed_cb (G_GNUC_UNUSED GtkWidget *entry, GdauiEntryWrapper *mgwrap)
 {
 	/* @entry is not used */
 	if (! mgwrap->priv->signals_blocked) {
@@ -374,7 +381,7 @@ contents_changed_cb (GtkWidget *entry, GdauiEntryWrapper *mgwrap)
 }
 
 static void
-contents_activated_cb (GtkWidget *entry, GdauiEntryWrapper *mgwrap)
+contents_activated_cb (G_GNUC_UNUSED GtkWidget *entry, GdauiEntryWrapper *mgwrap)
 {
 	/* @entry is not used */
 	if (! mgwrap->priv->signals_blocked) {
