@@ -100,6 +100,7 @@ static void pack_entries_in_table (GdauiBasicForm *form);
 static void pack_entries_in_xml_layout (GdauiBasicForm *form, xmlNodePtr form_node);
 static void unpack_entries (GdauiBasicForm *form);
 static void destroy_entries (GdauiBasicForm *form);
+static gchar *create_text_label_for_sentry (SingleEntry *sentry, gchar **out_title);
 
 static void gdaui_basic_form_show_entry_actions (GdauiBasicForm *form, gboolean show_actions);
 static void gdaui_basic_form_set_entries_auto_default (GdauiBasicForm *form, gboolean auto_default);
@@ -183,7 +184,8 @@ gdaui_basic_form_get_type (void)
 			NULL,
 			sizeof (GdauiBasicForm),
 			0,
-			(GInstanceInitFunc) gdaui_basic_form_init
+			(GInstanceInitFunc) gdaui_basic_form_init,
+			0
 		};
 
 		type = g_type_register_static (GTK_TYPE_VBOX, "GdauiBasicForm", &info, 0);
@@ -300,7 +302,7 @@ gdaui_basic_form_init (GdauiBasicForm * wid)
 }
 
 /**
- * gdaui_basic_form_new
+ * gdaui_basic_form_new:
  * @data_set: a #GdaSet structure
  *
  * Creates a new #GdauiBasicForm widget using all the #GdaHolder objects provided in @data_set.
@@ -308,7 +310,7 @@ gdaui_basic_form_init (GdauiBasicForm * wid)
  * The global layout is rendered using a table (a #GtkTable), and an entry is created for each
  * node of @data_set.
  *
- * Returns: the new widget
+ * Returns: (transfer full): the new widget
  *
  * Since: 4.2
  */
@@ -369,7 +371,7 @@ get_rid_of_set (GdaSet *paramlist, GdauiBasicForm *form)
 }
 
 static void
-paramlist_holder_type_set_cb (GdaSet *paramlist, GdaHolder *param,
+paramlist_holder_type_set_cb (G_GNUC_UNUSED GdaSet *paramlist, GdaHolder *param,
 			      GdauiBasicForm *form)
 {
 	SingleEntry *sentry;
@@ -387,7 +389,7 @@ paramlist_holder_type_set_cb (GdaSet *paramlist, GdaHolder *param,
 
 
 static void
-paramlist_public_data_changed_cb (GdauiSet *paramlist, GdauiBasicForm *form)
+paramlist_public_data_changed_cb (G_GNUC_UNUSED GdauiSet *paramlist, GdauiBasicForm *form)
 {
 	/* here we want to re-define all the data entry widgets */
 	destroy_entries (form);
@@ -397,8 +399,9 @@ paramlist_public_data_changed_cb (GdauiSet *paramlist, GdauiBasicForm *form)
 }
 
 static void
-paramlist_param_attr_changed_cb (GdaSet *paramlist, GdaHolder *param,
-				 const gchar *att_name, const GValue *att_value, GdauiBasicForm *form)
+paramlist_param_attr_changed_cb (G_GNUC_UNUSED GdaSet *paramlist, GdaHolder *param,
+				 const gchar *att_name, G_GNUC_UNUSED const GValue *att_value,
+				 GdauiBasicForm *form)
 {
 	SingleEntry *sentry;
 
@@ -446,7 +449,33 @@ paramlist_param_attr_changed_cb (GdaSet *paramlist, GdaHolder *param,
 			gdaui_basic_form_entry_set_visible (form, param, !sentry->hidden);
 		}
 		else
-			paramlist_public_data_changed_cb (form->priv->set_info, form);	
+			paramlist_public_data_changed_cb (form->priv->set_info, form);
+	}
+	else if (!strcmp (att_name, GDA_ATTRIBUTE_NAME) ||
+		 !strcmp (att_name, GDA_ATTRIBUTE_DESCRIPTION)) {
+		if (sentry) {
+			gchar *str, *title;
+			str = create_text_label_for_sentry (sentry, &title);
+			gtk_label_set_text (GTK_LABEL (sentry->label), str);
+			g_free (str);
+			g_free (sentry->label_title);
+			sentry->label_title = title;
+			
+			if (! sentry->group->group->nodes_source) {
+				g_object_get (G_OBJECT (param), "description", &title, NULL);
+				if (title && *title)
+					gtk_widget_set_tooltip_text (sentry->label, title);
+				g_free (title);
+			}
+			else {
+				title = g_object_get_data (G_OBJECT (sentry->group->group->nodes_source->data_model),
+							   "descr");
+				if (title && *title)
+					gtk_widget_set_tooltip_text (sentry->label, title);
+			}
+		}
+		else
+			paramlist_public_data_changed_cb (form->priv->set_info, form);
 	}
 }
 
@@ -611,7 +640,7 @@ disconnect_single_entry_signals (SingleEntry *sentry)
 		sd->holder = NULL;
 	}
 	if (sentry->group_signals) {
-		gint i;
+		gsize i;
 		for (i = 0; i < sentry->group_signals->len; i++) {
 			SignalData sd = g_array_index (sentry->group_signals, SignalData,
 						       i);
@@ -679,6 +708,58 @@ destroy_entries (GdauiBasicForm *form)
 	}
 }
 
+static gchar *
+create_text_label_for_sentry (SingleEntry *sentry, gchar **out_title)
+{
+	gchar *label = NULL;
+	g_assert (out_title);
+	if (! sentry->group->group->nodes_source) {
+		g_object_get (G_OBJECT (sentry->single_param), "name", out_title, NULL);
+		if (!*out_title)
+			*out_title = g_strdup (_("Value"));
+		label = g_strdup_printf ("%s:", *out_title);
+		/*
+		g_object_get (G_OBJECT (param), "description", &title, NULL);
+		if (title && *title)
+			gtk_widget_set_tooltip_text (sentry->label, title);
+		g_free (title);
+		*/
+
+	}
+	else {
+		GSList *params;
+		gchar *title = NULL;
+
+		label = g_object_get_data (G_OBJECT (sentry->group->group->nodes_source->data_model), "name");
+		if (label)
+			title = g_strdup (label);
+		else {
+			GString *tstring = NULL;
+			for (params = sentry->group->group->nodes; params; params = params->next) {
+				g_object_get (G_OBJECT (GDA_SET_NODE (params->data)->holder),
+					      "name", &title, NULL);
+				if (title) {
+					if (tstring) 
+						g_string_append (tstring, ",\n");
+					else
+						tstring = g_string_new ("");
+					g_string_append (tstring, title);
+				}
+			}
+			if (tstring)
+				title = g_string_free (tstring, FALSE);
+		}
+
+		if (!title)
+			title = g_strdup (_("Value"));
+
+		label = g_strdup_printf ("%s:", title);
+		*out_title = title;
+	}
+
+	return label;
+}
+
 static void
 create_entry_widget (SingleEntry *sentry)
 {
@@ -737,7 +818,7 @@ create_entry_widget (SingleEntry *sentry)
 
 		param = GDA_HOLDER (GDA_SET_NODE (group->group->nodes->data)->holder);
 		sentry->single_param = param;
-			
+		
 		val = gda_holder_get_value (param);
 		default_val = gda_holder_get_default_value (param);
 		nnul = gda_holder_get_not_null (param);
@@ -800,10 +881,7 @@ create_entry_widget (SingleEntry *sentry)
 		/* label */
 		gchar *title;
 		gchar *str;
-		g_object_get (G_OBJECT (param), "name", &title, NULL);
-		if (!title)
-			title = g_strdup (_("Value"));
-		str = g_strdup_printf ("%s:", title);
+		str = create_text_label_for_sentry (sentry, &title);
 		sentry->label = gtk_label_new (str);
 		g_free (str);
 		g_object_ref_sink (sentry->label);
@@ -847,32 +925,8 @@ create_entry_widget (SingleEntry *sentry)
 		/* label */
 		gchar *title = NULL;
 		gchar *str;
-		GSList *params;
 
-		str = g_object_get_data (G_OBJECT (group->group->nodes_source->data_model), "name");
-		if (str)
-			title = g_strdup (str);
-		else {
-			GString *tstring = NULL;
-			for (params = sentry->group->group->nodes; params; params = params->next) {
-				g_object_get (G_OBJECT (GDA_SET_NODE (params->data)->holder),
-					      "name", &title, NULL);
-				if (title) {
-					if (tstring) 
-						g_string_append (tstring, ",\n");
-					else
-						tstring = g_string_new ("");
-					g_string_append (tstring, title);
-				}
-			}
-			if (tstring)
-				title = g_string_free (tstring, FALSE);
-		}
-
-		if (!title)
-			title = g_strdup (_("Value"));
-
-		str = g_strdup_printf ("%s:", title);
+		str = create_text_label_for_sentry (sentry, &title);
 		sentry->label = gtk_label_new (str);
 		g_free (str);
 		g_object_ref_sink (sentry->label);
@@ -1287,7 +1341,7 @@ mark_not_null_entry_labels (GdauiBasicForm *form, gboolean show_mark)
 }
 
 static void
-entry_contents_activated (GdauiDataEntry *entry, GdauiBasicForm *form)
+entry_contents_activated (G_GNUC_UNUSED GdauiDataEntry *entry, GdauiBasicForm *form)
 {
 	g_signal_emit (G_OBJECT (form), gdaui_basic_form_signals[ACTIVATED], 0);
 }
@@ -1394,7 +1448,7 @@ entry_contents_modified (GdauiDataEntry *entry, SingleEntry *sentry)
 }
 
 static void
-entry_expand_changed_cb (GdauiDataEntry *entry, SingleEntry *sentry)
+entry_expand_changed_cb (G_GNUC_UNUSED GdauiDataEntry *entry, SingleEntry *sentry)
 {
 	pack_entry_widget (sentry);
 }
@@ -1476,13 +1530,13 @@ parameter_changed_cb (GdaHolder *param, SingleEntry *sentry)
 }
 
 /**
- * gdaui_basic_form_set_as_reference
+ * gdaui_basic_form_set_as_reference:
  * @form: a #GdauiBasicForm widget
  *
  * Tells @form that the current values in the different entries are
  * to be considered as the original values for all the entries; the immediate
  * consequence is that any sub-sequent call to gdaui_basic_form_has_changed()
- * will return FALSE (of course until any entry is changed).
+ * will return %FALSE (of course until any entry is changed).
  *
  * Since: 4.2
  */
@@ -1533,12 +1587,12 @@ gdaui_basic_form_set_as_reference (GdauiBasicForm *form)
 }
 
 /**
- * gdaui_basic_form_is_valid
+ * gdaui_basic_form_is_valid:
  * @form: a #GdauiBasicForm widget
  *
  * Tells if the form can be used as-is (if all the parameters do have some valid values)
  *
- * Returns: TRUE if the form is valid
+ * Returns: %TRUE if the form is valid
  *
  * Since: 4.2
  */
@@ -1551,13 +1605,13 @@ gdaui_basic_form_is_valid (GdauiBasicForm *form)
 }
 
 /**
- * gdaui_basic_form_get_data_set
+ * gdaui_basic_form_get_data_set:
  * @form: a #GdauiBasicForm widget
  *
  * Get a pointer to the #GdaSet object which
  * is modified by @form
  *
- * Returns: a pointer to the #GdaSet
+ * Returns: (transfer none): a pointer to the #GdaSet
  *
  * Since: 4.2
  */
@@ -1570,7 +1624,7 @@ gdaui_basic_form_get_data_set (GdauiBasicForm *form)
 }
 
 /**
- * gdaui_basic_form_has_changed
+ * gdaui_basic_form_has_changed:
  * @form: a #GdauiBasicForm widget
  *
  * Tells if the form has had at least on entry changed since @form was created or
@@ -1624,7 +1678,7 @@ gdaui_basic_form_show_entry_actions (GdauiBasicForm *form, gboolean show_actions
 }
 
 /**
- * gdaui_basic_form_reset
+ * gdaui_basic_form_reset:
  * @form: a #GdauiBasicForm widget
  *
  * Resets all the entries in the form to their
@@ -1662,7 +1716,7 @@ gdaui_basic_form_reset (GdauiBasicForm *form)
 
 
 /**
- * gdaui_basic_form_entry_set_visible
+ * gdaui_basic_form_entry_set_visible:
  * @form: a #GdauiBasicForm widget
  * @param: a #GdaHolder object
  * @show: set to %TRUE to show the data entry, and to %FALSE to hide it
@@ -1725,7 +1779,7 @@ gdaui_basic_form_entry_set_visible (GdauiBasicForm *form, GdaHolder *param, gboo
 }
 
 /**
- * gdaui_basic_form_entry_grab_focus
+ * gdaui_basic_form_entry_grab_focus:
  * @form: a #GdauiBasicForm widget
  * @param: a #GdaHolder object
  *
@@ -1747,9 +1801,9 @@ gdaui_basic_form_entry_grab_focus (GdauiBasicForm *form, GdaHolder *param)
 }
 
 /**
- * gdaui_basic_form_entry_set_editable
+ * gdaui_basic_form_entry_set_editable:
  * @form: a #GdauiBasicForm widget
- * @holder: a #GdaHolder object; or %NULL
+ * @holder: (allow-none): a #GdaHolder object; or %NULL
  * @editable: %TRUE if corresponding data entry must be editable
  *
  * Sets the #GdauiDataEntry in @form which corresponds to the
@@ -1807,7 +1861,7 @@ gdaui_basic_form_set_entries_auto_default (GdauiBasicForm *form, gboolean auto_d
 }
 
 /**
- * gdaui_basic_form_set_entries_to_default
+ * gdaui_basic_form_set_entries_to_default:
  * @form: a #GdauiBasicForm widget
  *
  * For each entry in the form, sets it to a default value if it is possible to do so.
@@ -1875,13 +1929,13 @@ get_single_entry_for_id (GdauiBasicForm *form, const gchar *id)
 }
 
 /**
- * gdaui_basic_form_get_entry_widget
+ * gdaui_basic_form_get_entry_widget:
  * @form: a #GdauiBasicForm widget
  * @param: a #GdaHolder object
  *
  * Get the #GdauiDataEntry in @form which corresponds to the param parameter.
  *
- * Returns: the requested widget, or %NULL if not found
+ * Returns: (transfer none): the requested widget, or %NULL if not found
  *
  * Since: 4.2
  */
@@ -1900,13 +1954,13 @@ gdaui_basic_form_get_entry_widget (GdauiBasicForm *form, GdaHolder *param)
 }
 
 /**
- * gdaui_basic_form_get_label_widget
+ * gdaui_basic_form_get_label_widget:
  * @form: a #GdauiBasicForm widget
  * @param: a #GdaHolder object
  *
  * Get the label in @form which corresponds to the param parameter.
  *
- * Returns: the requested widget, or %NULL if not found
+ * Returns: (transfer none): the requested widget, or %NULL if not found
  *
  * Since: 4.2
  */
@@ -1925,11 +1979,11 @@ gdaui_basic_form_get_label_widget (GdauiBasicForm *form, GdaHolder *param)
 }
 
 /**
- * gdaui_basic_form_new_in_dialog
+ * gdaui_basic_form_new_in_dialog:
  * @data_set: a #GdaSet object
- * @parent: the parent window for the new dialog, or %NULL
- * @title: the title of the dialog window, or %NULL
- * @header: a helper text displayed at the top of the dialog, or %NULL
+ * @parent: (allow-none): the parent window for the new dialog, or %NULL
+ * @title: (allow-none): the title of the dialog window, or %NULL
+ * @header: (allow-none): a helper text displayed at the top of the dialog, or %NULL
  *
  * Creates a new #GdauiBasicForm widget in the same way as gdaui_basic_form_new()
  * and puts it into a #GtkDialog widget. The returned dialog has the "Ok" and "Cancel" buttons
@@ -1938,7 +1992,7 @@ gdaui_basic_form_get_label_widget (GdauiBasicForm *form, GdaHolder *param)
  * The #GdauiBasicForm widget is attached to the dialog using the user property
  * "form".
  *
- * Returns: the new #GtkDialog widget
+ * Returns: (transfer full): the new #GtkDialog widget
  *
  * Since: 4.2
  */
@@ -2005,7 +2059,8 @@ gdaui_basic_form_new_in_dialog (GdaSet *data_set, GtkWindow *parent,
 }
 
 static void
-form_holder_changed (GdauiBasicForm *form, GdaHolder *param, gboolean is_user_modif, GtkDialog *dlg)
+form_holder_changed (GdauiBasicForm *form, G_GNUC_UNUSED GdaHolder *param,
+		     G_GNUC_UNUSED gboolean is_user_modif, GtkDialog *dlg)
 {
 	gboolean valid;
 
@@ -2015,7 +2070,7 @@ form_holder_changed (GdauiBasicForm *form, GdaHolder *param, gboolean is_user_mo
 }
 
 /**
- * gdaui_basic_form_set_layout_from_file
+ * gdaui_basic_form_set_layout_from_file:
  * @form: a #GdauiBasicForm
  * @file_name: XML file name to use
  * @form_name: the name of the form to use, in @file_name
@@ -2084,13 +2139,14 @@ gdaui_basic_form_set_layout_from_file (GdauiBasicForm *form, const gchar *file_n
 }
 
 /**
- * gdaui_basic_form_get_place_holder
+ * gdaui_basic_form_get_place_holder:
  * @form: a #GdauiBasicForm
  * @placeholder_id: the name of the requested place holder
  *
- * Retreives a pointer to a place holder widget
+ * Retreives a pointer to a place holder widget. This feature is only available if a specific
+ * layout has been defined for @form using gdaui_basic_form_set_layout_from_file().
  *
- * Returns: a pointer to the requested place holder, or %NULL if not found
+ * Returns: (transfer none): a pointer to the requested place holder, or %NULL if not found
  *
  * Since: 4.2
  */
@@ -2106,7 +2162,7 @@ gdaui_basic_form_get_place_holder (GdauiBasicForm *form, const gchar *placeholde
 }
 
 /**
- * gdaui_basic_form_add_to_size_group
+ * gdaui_basic_form_add_to_size_group:
  * @form: a #GdauiBasicForm
  * @size_group: a #GtkSizeGroup object
  * @part: specifies which widgets in @form are concerned
@@ -2147,7 +2203,7 @@ gdaui_basic_form_add_to_size_group (GdauiBasicForm *form, GtkSizeGroup *size_gro
 }
 
 /**
- * gdaui_basic_form_remove_from_size_group
+ * gdaui_basic_form_remove_from_size_group:
  * @form: a #GdauiBasicForm
  * @size_group: a #GtkSizeGroup object
  * @part: specifies which widgets in @form are concerned
