@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2009 - 2010 The GNOME Foundation.
+ * Copyright (C) 2009 - 2011 The GNOME Foundation.
  *
  * AUTHORS:
  *      Vivien Malerba <malerba@gnome-db.org>
@@ -19,6 +19,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <unistd.h>
 #include <glib/gi18n-lib.h>
 #include <glib/gprintf.h>
 #include <string.h>
@@ -30,6 +31,7 @@
 #include "login-dialog.h"
 #include "auth-dialog.h"
 #include "browser-stock-icons.h"
+#include "../config-info.h"
 
 /* Perspectives' factories */
 #include "schema-browser/perspective-main.h"
@@ -50,12 +52,35 @@ main_browser_core_init_factories (void)
 	return factories;
 }
 
+static void
+output_data_model (GdaDataModel *model)
+{
+	if (! getenv ("GDA_DATA_MODEL_DUMP_TITLE"))
+		g_setenv ("GDA_DATA_MODEL_DUMP_TITLE", "Yes", TRUE);
+	if (! getenv ("GDA_DATA_MODEL_NULL_AS_EMPTY"))
+		g_setenv ("GDA_DATA_MODEL_NULL_AS_EMPTY", "Yes", TRUE);
+	if (isatty (fileno (stdout))) {
+		if (! getenv ("GDA_DATA_MODEL_DUMP_TRUNCATE"))
+			g_setenv ("GDA_DATA_MODEL_DUMP_TRUNCATE", "-1", TRUE);
+	}
+	gda_data_model_dump (model, NULL);	
+}
+
+
 /* options */
 gchar *perspective = NULL;
+gboolean list_configs = FALSE;
+gboolean list_providers = FALSE;
+gboolean list_data_files = FALSE;
+gchar *purge_data_files = NULL;
 
 static GOptionEntry entries[] = {
         { "perspective", 'p', 0, G_OPTION_ARG_STRING, &perspective, "Perspective", "default perspective "
 	  "to use when opening windows"},
+        { "list-dsn", 'l', 0, G_OPTION_ARG_NONE, &list_configs, "List configured data sources and exit", NULL },
+        { "list-providers", 'L', 0, G_OPTION_ARG_NONE, &list_providers, "List installed database providers and exit", NULL },
+        { "data-files-list", 0, 0, G_OPTION_ARG_NONE, &list_data_files, "List files used to hold information related to each connection", NULL },
+        { "data-files-purge", 0, 0, G_OPTION_ARG_STRING, &purge_data_files, "Remove some files used to hold information related to each connection", "criteria"},
 	{ NULL, 0, 0, 0, NULL, NULL, NULL }
 };
 
@@ -78,6 +103,66 @@ main (int argc, char *argv[])
         }
         g_option_context_free (context);
 
+	/* treat here lists of providers and defined DSN */
+	if (list_providers) {
+		gda_init ();
+		GdaDataModel *model;
+		if (argc == 2)
+			model = config_info_detail_provider (argv[1], &error);
+		else
+			model = config_info_list_all_providers ();
+
+		if (model) {
+			output_data_model (model);
+			g_object_unref (model);
+		}
+		else {
+			g_print (_("Error: %s\n"), 
+				 error && error->message ? error->message : _("No detail"));
+			g_clear_error (&error);
+		}
+		return 0;
+	}
+	if (list_configs) {
+		gda_init ();
+		GdaDataModel *model = config_info_list_all_dsn ();
+		output_data_model (model);
+		g_object_unref (model);
+		return 0;
+	}
+	if (list_data_files) {
+		gchar *confdir;
+		GdaDataModel *model;
+
+		gda_init ();
+		confdir = config_info_compute_dict_directory ();
+		g_print (_("All files are in the directory: %s\n"), confdir);
+		g_free (confdir);
+		model = config_info_list_data_files (&error);
+		if (model) {
+			output_data_model (model);
+			g_object_unref (model);
+		}
+		else
+			g_print (_("Can't get the list of files used to store information about each connection: %s\n"),
+				 error->message);	
+		return 0;
+	}
+	if (purge_data_files) {
+		gchar *tmp;
+
+		gda_init ();
+		tmp = config_info_purge_data_files (purge_data_files, &error);
+		if (tmp) {
+			g_print ("%s\n", tmp);
+			g_free (tmp);
+		}
+		if (error)
+			g_print (_("Error while purging files used to store information about each connection: %s\n"),
+				 error->message);	
+		return 0;
+	}
+
 	gdaui_init ();
 	gtk_init (&argc, &argv);
 #ifdef HAVE_MAC_INTEGRATION
